#
# spec file for package cln
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cln
Version:        1.3.7
Release:        1.2
Summary:        Class Library for Numbers (C++)
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://www.ginac.de/CLN/
Source0:        https://www.ginac.de/CLN/cln-%{version}.tar.bz2
Source1:        pi.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  pkgconfig
BuildRequires:  texinfo
Requires(pre):  %{install_info_prereq}
Provides:       libcln
Provides:       pi

%description
CLN features a rich set of number classes: integer (unlimited
precision), rational, short float, single float, double float, long
float (unlimited precision), complex, modular integer, and univariate
polynomial.  It implements elementary, logical, and transcendental
functions.  C++ as the implementation language brings efficiency, type
safety, and algebraic syntax.  Memory efficiency: small integers and
short floats are immediate, not heap allocated. Automatic,
noninterruptive garbage collection.  Speed efficiency: assembly
language kernel for some CPUs, Karatsuba and Schoenhage-Strassen
multiplication.  Interoperability: garbage collection with no burden on
the main application, hooks for memory allocation and exceptions.

The following C++ features are used: classes, member functions,
overloading of functions and operators, constructors and destructors,
inline, const, multiple inheritance, templates, and namespaces.  The
following C++ features are not used: new, delete, virtual inheritance,
and exceptions.

%package devel
Summary:        Class Library for Numbers (C++)
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires(pre):  %{install_info_prereq}

%description devel
CLN features a rich set of number classes: integer (unlimited
precision), rational, short float, single float, double float, long
float (unlimited precision), complex, modular integer, and univariate
polynomial.  It implements elementary, logical, and transcendental
functions.  C++ as the implementation language brings efficiency, type
safety, and algebraic syntax.  Memory efficiency: small integers and
short floats are immediate, not heap allocated. Automatic,
noninterruptive garbage collection.  Speed efficiency: assembly
language kernel for some CPUs, Karatsuba and Schoenhage-Strassen
multiplication.  Interoperability: garbage collection with no burden on
the main application, hooks for memory allocation and exceptions.

The following C++ features are used: classes, member functions,
overloading of functions and operators, constructors and destructors,
inline, const, multiple inheritance, templates, and namespaces.  The
following C++ features are not used: new, delete, virtual inheritance,
and exceptions.

%prep
%setup -q -a 1

%build
%ifarch %{arm}
%global XFLAGS %{optflags} -DNO_ASM
%else
%global XFLAGS %{optflags}
%endif
CFLAGS="%{XFLAGS} -fno-unit-at-a-time" \
CXXFLAGS="%{XFLAGS} -fno-strict-aliasing -fno-unit-at-a-time -fno-reorder-blocks" \
%configure --disable-static
make %{?_smp_mflags}
make %{?_smp_mflags} check
#cd benchmarks
#for i in a ap b ; do
#	./timebench2$i -r 10
#done
#cd ..
g++ %{optflags} -I./include pi.cc -o pi -L./src/.libs/ -lcln -lgmp
make %{?_smp_mflags} html

%install
mkdir -p %{buildroot}%{_docdir}/cln
make DESTDIR=%{buildroot} MANDIR=%{_mandir} htmldir=%{_docdir}/cln install
install -m 755 pi %{buildroot}%{_bindir}
rm -f %{buildroot}%{_libdir}/libcln.la

%check
make %{?_smp_mflags} check

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%doc ChangeLog README NEWS
%license COPYING
%{_bindir}/pi
%{_libdir}/libcln.so.*

%files devel
%doc ChangeLog README NEWS
%license COPYING
%{_includedir}/cln
%{_infodir}/cln.info%{?ext_info}
%{_mandir}/man1/pi.1%{?ext_man}
%{_libdir}/libcln.so
%{_libdir}/pkgconfig/cln.pc

%changelog
* Thu Feb  8 2024 pgajdos@suse.com
- version update to 1.3.7
  * Fixed compilation on ARM platforms.
  * Add support for LoongArch.
* Mon Sep 21 2020 pgajdos@suse.com
- remove -fvisibility-inlines-hidden for now [bsc#1176710]
* Thu Dec 19 2019 pgajdos@suse.com
- version update to 1.3.6
  * fix build errors
- run tests
* Wed Nov 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.3.5:
  * Fix bug in scale_float() throwing underflow_exception.
- Drop riscv.patch. Fixed upstream.
* Mon Mar 11 2019 Andreas Schwab <schwab@suse.de>
- riscv.patch: Add support for riscv64 platform
- Use %%license
* Tue Nov 18 2014 pgajdos@suse.com
- updated to 1.3.4:
  * Fix input of huge floats.
  * Support the AArch64 and the Mips64 ABIs.
    => dropped cln-aarch64.patch
* Mon Sep  9 2013 pgajdos@suse.com
- updated to 1.3.3:
  * Fix integer input of leading zeros in power-of-two base.
  * Fix several floating-poing conversion bugs involving huge
    numbers.
  * Fix bug that would set input stream fail state when reading
    a number at EOF.
- removed upstreamed s390x.patch
- refreshed aarch64.patch
* Wed Mar  6 2013 schwab@suse.de
- cln-aarch64.patch: add support for aarch64
* Tue Nov 20 2012 cgiboudeaux@gmx.com
- Fix the SLES build (%%make_install is not expanded)
- Install the license file
* Fri Jan 20 2012 crrodriguez@opensuse.org
- build with -fvisibility-inlines-hidden, in the unlikely
  case this cause trouble, drop me a note (the test suite passes
  so I expect none) . This reduces the exported symbol table
  in around 200(!!) symbols.
* Tue Dec 20 2011 dmueller@suse.de
- build with optflags again
- fix build on arm
* Mon Nov 28 2011 ro@suse.de
- make it build on s390x
* Mon Oct 17 2011 arun@gmx.de
- Update to version 1.3.2: (changes taken from git log)
  * Fix scale_float for large factors on x86.
  * Update documentation about infrastructure requirements.
  * Support for MSVC.
  * Fix yet another dependent base C++ language issue.
  * Fix compilation with clang.
  * Configure: be more cross-compilation friendly.
  * Fix the documentation build failure (wrong texinfo).
  * Remove 'auto' keyword used as storage specifier.
* Mon Aug  8 2011 toddrme2178@gmail.ccom
- Fixed group (fix for RPMLINT warning)
- Removed commented files  (fix for RPMLINT warning)
- Switched hard-coded paths and commands to RPM macros in spec file
- Cleaned up spec file formatting
* Mon Jun 28 2010 pgajdos@suse.cz
- Added pkg-config to BuildRequires to generate right Provides
* Mon Sep 28 2009 masterpatricko@gmail.com
- Update to verion 1.3.1
* Sat Aug  8 2009 masterpatricko@gmail.com
- Update to version 1.3
* Mon Mar 17 2008 bwalle@suse.de
- fix build on ia64
* Wed Dec 19 2007 bwalle@suse.de
- fix build for gcc 4.3 after the gmp update (CL_GMP_SET_UINTD
  needs to be run with C and not with C++ language)
- require emacs-nox instead of emacs-x11 because emacs-x11 requires
  a terminal as standard input even in batch mode
- changed RPM Group for devel subpackage to "Development/Lib-
  raries/C and C++" because of rpmlint
* Wed Oct 24 2007 bwalle@suse.de
- update to latest CVS
- fix build for gcc 4.3
* Fri Jun 22 2007 bwalle@suse.de
- update to 1.1.13
  o Compilation fixes for 64-bit
  o Fix rare assertion when printing quite large floats.
  o Compilation fixes for several platforms: *BSD, Intel Mac, and
    MinGW.
- created -devel subpackage
- fixed dependency for 10.3
* Thu Mar 23 2006 schwab@suse.de
- Don't generate debug information twice.
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%%%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 ro@suse.de
- added gmp-devel to nfb
* Thu Nov 24 2005 jj@suse.de
- update to new version, disabled patch
* Mon May 23 2005 schwab@suse.de
- Add  -fno-reorder-blocks to work around design bug.
- Fix missing declaration.
* Thu Jan 27 2005 uli@suse.de
- update -> 1.1.9 (bugfixes, speedups, new function sintL
  ldegree(const cl_UP& x))
* Fri Jan  9 2004 adrian@suse.de
- add %%%%run_ldconfig
* Thu Nov  6 2003 ro@suse.de
- use -fno-unit-at-a-time (constructor detection in configure)
* Thu Jul 10 2003 meissner@suse.de
- Fixed ppc64 fix (use __powerpc64__, not __ppc64__). Now crashes
  the assembler with slightly invalid assembler.
- Added s390x.
- Merged all diffs into 1.
* Mon Jul  7 2003 meissner@suse.de
- Reenabled make check.
- Fixed ppc/ppc64 build.
- Fixed ia64 build.
- Fixed so that it will at least run the testsuite on x86_64.
* Thu Jul  3 2003 jj@suse.de
- support for ppc64: cln-1.1.5-ppc64.diff
- RPM_OPT_FLAGS
* Thu Jun 19 2003 ro@suse.de
- fix filelist
* Mon May 26 2003 ro@suse.de
- added info page to filelist
- added info page installation handling
* Mon Feb 24 2003 ro@suse.de
- use libdir
* Wed Feb  5 2003 jj@suse.de
- disabled 'make check' because it is expensive
* Fri Aug  2 2002 jj@suse.de
- update to version 1.1.5 (bugfix-version)
* Tue Jun 11 2002 stepan@suse.de
- add type defines for x86-64
* Mon Jan 14 2002 schwab@suse.de
- Fix use of namespaces.
* Sat Dec  8 2001 jj@suse.de
- update to version 1.1.3
* Thu Aug 30 2001 jj@suse.de
- upgraded to 1.1.2 that should fix all problems
- disabled patches cln-ia64.dif and cln-namesp.dif
* Mon Jul 16 2001 schwab@suse.de
- Fix namespace bug.
* Wed Apr  4 2001 jj@suse.de
- fixed permissions for /usr/bin/pi
* Wed Mar  7 2001 jj@suse.de
- entered patch for ia64
- added example program /usr/bin/pi  ;-)
* Mon Feb 19 2001 jj@suse.de
- initial version
